@@ -1,5 +1,11 @@
-from easypost.requestor import Requestor
+from typing import List
+
+from easypost.requestor import (
+    RequestMethod,
+    Requestor,
+)
 from easypost.resource import CreateResource
+from easypost.util import get_lowest_object_rate
 
 
 class Pickup(CreateResource):
@@ -7,7 +13,7 @@ class Pickup(CreateResource):
         """Buy a pickup."""
         requestor = Requestor(local_api_key=self._api_key)
         url = "%s/%s" % (self.instance_url(), "buy")
-        response, api_key = requestor.request(method="post", url=url, params=params)
+        response, api_key = requestor.request(method=RequestMethod.POST, url=url, params=params)
         self.refresh_from(values=response, api_key=api_key)
         return self
 
@@ -15,6 +21,12 @@ class Pickup(CreateResource):
         """Cancel a pickup."""
         requestor = Requestor(local_api_key=self._api_key)
         url = "%s/%s" % (self.instance_url(), "cancel")
-        response, api_key = requestor.request(method="post", url=url, params=params)
+        response, api_key = requestor.request(method=RequestMethod.POST, url=url, params=params)
         self.refresh_from(values=response, api_key=api_key)
         return self
+
+    def lowest_rate(self, carriers: List[str] = None, services: List[str] = None):
+        """Get the lowest rate of this pickup."""
+        lowest_rate = get_lowest_object_rate(self, carriers, services, "pickup_rates")
+
+        return lowest_rate
